1.1
===

Refreshed packaging. Tests now run on some non-Windows environments.

Initial Python 3 support.

Blowfish module is deprecated on Python 3. Use `blowfish
<https://pypi.org/project/blowfish>`_ instead.

1.0
===

Initial release
